@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # Eval and Print commands.
 #
-#   Copyright (C) 2008, 2010-2011, 2014-2015 Rocky Bernstein
+#   Copyright (C) 2008, 2010-2011, 2014-2015, 2017 Rocky Bernstein
 #   <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
@@ -39,7 +39,7 @@ _Dbg_help_add eval \
 
 **eval?**
 
-In the first form *cmd* is a string *cmd* is a string sent to special
+In the first form *cmd* is a string; *cmd* is a string sent to special
 shell builtin eval.
 
 In the second form, use evaluate the current source line text.
@@ -50,16 +50,25 @@ statement, one wants to eval is just the expression portion.  For
 this, use eval?. Actually, any alias that ends in ? which is aliased
 to eval will do thie same thing.
 
+If no string is given, we run the string from the current source code
+about to be run. If the command ends `?` (via an alias) and no string is
+given, the following translations occur:
+
+    {if|elif} <expr> [; then] => <expr>
+    while <expr> [; do]?      => <expr>
+    return <expr>             => <expr>
+    <var>=<expr>              => <expr>
+
 See also:
 ---------
 
-**print** and **set autoeval**.'
+**set autoeval**, **print** and **examine**.'
 
 typeset -i _Dbg_show_eval_rc; _Dbg_show_eval_rc=1
 
 _Dbg_do_eval() {
 
-    print ". ${_Dbg_libdir}/lib/set-d-vars.sh" > $_Dbg_evalfile
+    print ". ${_Dbg_libdir}/lib/set-d-vars.sh" > "$_Dbg_evalfile"
     if (( $# == 0 )) ; then
         # FIXME: add parameter to get unhighlighted line, or
         # always save a copy of that in _Dbg_sget_source_line
@@ -90,14 +99,14 @@ _Dbg_do_eval() {
             source_line_save="$extracted"
         fi
 
-        print "$source_line" >> $_Dbg_evalfile
+        print "$source_line" >> "$_Dbg_evalfile"
         _Dbg_msg "eval: ${source_line}"
         _Dbg_source_line="$source_line_save"
         _Dbg_set_highlight=$_Dbg_highlight_save
     else
-        print "$@" >> $_Dbg_evalfile
+        print "$@" >> "$_Dbg_evalfile"
     fi
-    print '_Dbg_rc=$?' >> $_Dbg_evalfile
+    print '_Dbg_rc=$?' >> "$_Dbg_evalfile"
     typeset -i _Dbg_rc
     if [[ -t $_Dbg_fdi  ]] ; then
         _Dbg_set_dol_q $_Dbg_debugged_exit_code
