@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # "set autoeval" debugger command
 #
-#   Copyright (C) 2011, 2014, 2016 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2011, 2014, 2016-2017 Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -32,7 +32,22 @@ _Dbg_complete_level_2_data[set_autoeval]='on off'
 _Dbg_help_add_sub set autoeval \
 '**set autoeval** [**on**|**off**]
 
-Evaluate unrecognized commands
+Evaluate unrecognized debugger commands.
+
+Often inside the debugger, one would like to be able to run arbitrary
+Python commands without having to preface Python expressions with
+``print`` or ``eval``. Setting *autoeval* on will cause unrecognized
+debugger commands to be *eval* as a Python expression.
+
+Note that if this is set, on error the message shown on type a bad
+debugger command changes from:
+
+      Undefined command: "fdafds". Try "help".
+
+to something more zsh-eval-specific such as:
+
+      /tmp/zshdb_eval_26397:2: command not found: fdafds
+
 
 See also:
 ---------
